==> hp300_1.0.tar: hp300/examples/concepts/basic1.ex <==
#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
(revision "A.00.00")
(date "Wed 10/Apr/1991")
(component 0 "Context"
 (name "Simple HP BASIC Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "HPBasic"
   (name "Init HP BASIC/UX")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (component progname "/usr/lib/veetest/examples/concepts/simple.bas")
   )
   (views
    (icon
    )
    (detail
     (origin 606 190)
     (extent 228 34)
    )
    (active detail)
   )
  )
  (component 1 "Start"
   (name "Start")
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 686 88)
     (extent 69 39)
    )
    (detail
     (origin 586 400)
     (extent 129 20)
    )
    (active icon)
   )
  )
  (component 2 "NamedPipe"
   (name "To/From HP BASIC/UX")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (attr iopath file read "/tmp/from_rmb"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (attr iopath file append "/tmp/to_rmb"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (procedure
      WRITE TEXT a EOL
      READ TEXT x REAL COUNT:1
    )
   )
   (views
    (icon
     (iconImage basic.icon)
    )
    (detail
     (origin 585 284)
     (extent 271 167)
    )
    (active detail)
   )
  )
  (component 3 "Constant"
   (name "in")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Real
     (name "in")
     (datum 3)
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Real
     (datum 0)
    )
   )
   (views
    (icon
     (extent 46 0)
    )
    (detail
     (origin 476 354)
     (extent 88 27)
    )
    (active detail)
   )
  )
  (component 4 "TextDisplay"
   (name "out")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 907 348)
     (extent 46 25)
    )
    (detail
     (origin 881 353)
     (extent 98 35)
    )
    (active detail)
   )
  )
  (component 5 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 482 519)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 6 "Note"
   (name "Overview of simple HP BASIC/UX example")
   (interface
   )
   (implementation
    (component text 41 5
     Pupose: Show how to start an HP BASIC/UX
     process and exchange simple data with it.
     
     Explanation:
     The "Init HP BASIC/UX" object inititates an
     HP BASIC/UX process which loads and runs
     the specified file.  If an HP BASIC/UX 
     process is already running from a previous
     execution of the object, then this object
     does nothing when it gets pinged.
     
     Any named pipes can be used for 
     communication to an HP BASIC/UX process.
     No mechanism exists within HP VEE Test to
     clear named pipes.  An "HP-UX escape" can be
     used for that purpose.
     
     The transactions in the "To/From HP BASIC/UX"
     object are the same ones used in other I/O
     objects.  The pipe will queue all WRITEs 
     from HP VEE Test whether another process
     is consuming the results or not.  The READ 
     transaction looks for data in the Read Pipe.
     The transaction will wait until it has 
     sufficient data to satisfy itself.  If 
     insufficient is available then the object
     cannot complete its execution and will appear
     to "hang" on that transaction.
     
     When the model has completed its execution,
     the HP BASIC/UX process remains.  If the
     HP BASIC/UX program enters the idle state,
     running the HP VEE Test model will not 
     cause the HP BASIC/UX program to start
     running.  The HP BASIC program executes a
     QUIT statement which terminates its own 
     process.
     
     Edit the simple.bas program to see what is
     needed on the HP BASIC/UX end.
     
    )
   )
   (views
    (icon
     (extent 352 0)
    )
    (detail
     (origin 10 118)
     (extent 441 619)
     (editing disabled)
    )
    (active detail)
   )
  )
  (configuration
   (connect D1:0 D0:0)
   (connect D3:1 D2:1)
   (connect D0:0 D3:0)
   (connect D2:1 D4:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 979 658)
   (configuration
    (connect D1:0 D0:0
     (Point 720 129)
     (Point 720 157)
    )
    (connect D3:1 D2:1
     (Point 566 367)
     (Point 574 367)
     (Point 574 367)
     (Point 582 367)
    )
    (connect D0:0 D3:0
     (Point 720 226)
     (Point 720 241)
     (Point 520 241)
     (Point 520 321)
    )
    (connect D2:1 D4:1
     (Point 858 367)
     (Point 881 367)
     (Point 881 370)
     (Point 878 370)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)

==> hp300_1.1.tar: hp300/examples/concepts/basic1.ex <==
#! /usr/lib/veetest/veetest -r
(revision "A.00.00")
(date "Wed 10/Apr/1991")
(component 0 "Context"
 (name "Simple HP BASIC Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "HPBasic"
   (name "Init HP BASIC/UX")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (component progname "/usr/lib/veetest/examples/concepts/simple.bas")
   )
   (views
    (icon
    )
    (detail
     (origin 606 190)
     (extent 228 34)
    )
    (active detail)
   )
  )
  (component 1 "Start"
   (name "Start")
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 686 88)
     (extent 69 39)
    )
    (detail
     (origin 586 400)
     (extent 129 20)
    )
    (active icon)
   )
  )
  (component 2 "NamedPipe"
   (name "To/From HP BASIC/UX")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (attr iopath file read "/tmp/from_rmb"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (attr iopath file append "/tmp/to_rmb"
     (readTerm "\n")
     (fs " ")
     (eol "\n")
     (multiField fullSyntax)
     (arrayFormat block)
    )
    (procedure
      WRITE TEXT a EOL
      READ TEXT x REAL COUNT:1
    )
   )
   (views
    (icon
     (iconImage basic.icon)
    )
    (detail
     (origin 585 284)
     (extent 271 167)
    )
    (active detail)
   )
  )
  (component 3 "Constant"
   (name "in")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Real
     (name "in")
     (datum 3)
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Real
     (datum 0)
    )
   )
   (views
    (icon
     (extent 46 0)
    )
    (detail
     (origin 476 354)
     (extent 88 27)
    )
    (active detail)
   )
  )
  (component 4 "TextDisplay"
   (name "out")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 907 348)
     (extent 46 25)
    )
    (detail
     (origin 881 353)
     (extent 98 35)
    )
    (active detail)
   )
  )
  (component 5 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 482 519)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 6 "Note"
   (name "Overview of simple HP BASIC/UX example")
   (interface
   )
   (implementation
    (component text 41 5
     Purpose: Show how to start an HP BASIC/UX
     process and exchange simple data with it.
     
     Explanation:
     The "Init HP BASIC/UX" object initiates an
     HP BASIC/UX process which loads and runs
     the specified file.  If an HP BASIC/UX 
     process is already running from a previous
     execution of the object, then this object
     does nothing when it gets pinged.
     
     Any named pipes can be used for 
     communication to an HP BASIC/UX process.
     No mechanism exists within HP VEE Test to
     clear named pipes.  An "HP-UX escape" can be
     used for that purpose.
     
     The transactions in the "To/From HP BASIC/UX"
     object are the same ones used in other I/O
     objects.  The pipe will queue all WRITEs 
     from HP VEE Test whether another process
     is consuming the results or not.  The READ 
     transaction looks for data in the Read Pipe.
     The transaction will wait until it has 
     sufficient data to satisfy itself.  If 
     insufficient is available then the object
     cannot complete its execution and will appear
     to "hang" on that transaction.
     
     When the model has completed its execution,
     the HP BASIC/UX process remains.  If the
     HP BASIC/UX program enters the idle state,
     running the HP VEE Test model will not 
     cause the HP BASIC/UX program to start
     running.  The HP BASIC program executes a
     QUIT statement which terminates its own 
     process.
     
     Edit the simple.bas program to see what is
     needed on the HP BASIC/UX end.
     
    )
   )
   (views
    (icon
     (extent 352 0)
    )
    (detail
     (origin 10 118)
     (extent 441 619)
     (editing disabled)
    )
    (active detail)
   )
  )
  (configuration
   (connect D1:0 D0:0)
   (connect D3:1 D2:1)
   (connect D0:0 D3:0)
   (connect D2:1 D4:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 979 658)
   (configuration
    (connect D1:0 D0:0
     (Point 720 129)
     (Point 720 157)
    )
    (connect D3:1 D2:1
     (Point 566 367)
     (Point 574 367)
     (Point 574 367)
     (Point 582 367)
    )
    (connect D0:0 D3:0
     (Point 720 226)
     (Point 720 241)
     (Point 520 241)
     (Point 520 321)
    )
    (connect D2:1 D4:1
     (Point 858 367)
     (Point 881 367)
     (Point 881 370)
     (Point 878 370)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
